@@ -15,6 +15,7 @@
 
 import logging
 
+from osc_lib.cli import format_columns
 from osc_lib.command import command
 from osc_lib import exceptions
 from osc_lib import utils
@@ -27,6 +28,11 @@ from openstackclient.network import sdk_utils
 LOG = logging.getLogger(__name__)
 
 
+_formatters = {
+    'location': format_columns.DictColumn,
+}
+
+
 def _get_columns(item):
     column_map = {
         'is_shared': 'shared',
@@ -100,7 +106,7 @@ class CreateAddressScope(command.ShowOne):
         attrs = _get_attrs(self.app.client_manager, parsed_args)
         obj = client.create_address_scope(**attrs)
         display_columns, columns = _get_columns(obj)
-        data = utils.get_item_properties(obj, columns, formatters={})
+        data = utils.get_item_properties(obj, columns, formatters=_formatters)
 
         return (display_columns, data)
 
@@ -204,10 +210,8 @@ class ListAddressScope(command.Lister):
         if parsed_args.ip_version:
             attrs['ip_version'] = parsed_args.ip_version
         if parsed_args.share:
-            attrs['shared'] = True
             attrs['is_shared'] = True
         if parsed_args.no_share:
-            attrs['shared'] = False
             attrs['is_shared'] = False
         if 'project' in parsed_args and parsed_args.project is not None:
             identity_client = self.app.client_manager.identity
@@ -291,6 +295,6 @@ class ShowAddressScope(command.ShowOne):
             parsed_args.address_scope,
             ignore_missing=False)
         display_columns, columns = _get_columns(obj)
-        data = utils.get_item_properties(obj, columns, formatters={})
+        data = utils.get_item_properties(obj, columns, formatters=_formatters)
 
         return (display_columns, data)
